@@ -5,6 +5,7 @@ import math
 import sys
 import textwrap
 import typing
+from typing import Optional, Type
 
 from . import constants, log, structs
 from .constants import AdsDataType
@@ -85,9 +86,10 @@ class Symbol:
         data_type: constants.AdsDataType,
         array_length: int,
         data_area: "DataArea",
-        type_name: str = None,
-        bit_offset: int = None,
+        type_name: Optional[str] = None,
+        bit_offset: Optional[int] = None,
         pointer: bool = False,
+        comment: Optional[str] = None,
     ):
         self.array_length = array_length
         self.data_area = data_area
@@ -97,6 +99,7 @@ class Symbol:
         self.offset = offset
         self.bit_offset = bit_offset
         self.pointer = pointer  # TODO: only depth of 1
+        self.comment = comment or ""
         self.log = log.ComposableLogAdapter(
             module_logger,
             extra=dict(
@@ -231,9 +234,8 @@ def tmc_to_symbols(
             bit_offset=bit_offset_obj,
             pointer=pointer,
             type_name=data_type.name,
+            comment=(item.Comment[0].text if hasattr(item, "Comment") else ""),
         )
-        if hasattr(item, "Comment"):
-            symbol.__doc__ = item.Comment[0].text
 
         yield symbol
     else:
@@ -303,9 +305,40 @@ class BasicSymbol(Symbol):
 
 
 class ComplexSymbol(Symbol):
-    def __init__(self, *, struct_size: int, **kwargs):
+    def __init__(
+        self,
+        *,
+        struct_size: Optional[int] = None,
+        data_type: AdsDataType = AdsDataType.BIGTYPE,
+        cls: Optional[Type[ctypes.Structure]] = None,
+        **kwargs,
+    ):
+        if struct_size is None:
+            if cls is not None:
+                struct_size = ctypes.sizeof(cls)
+            else:
+                raise ValueError("Must specify structure class or byte size")
+
+        self.data_cls = cls
         self._struct_size = struct_size
-        super().__init__(**kwargs)
+        super().__init__(data_type=data_type, **kwargs)
+
+    def write(self, value):
+        if self.data_cls is not None and isinstance(value, self.data_cls):
+            byte_value = bytes(value)
+            self.log.debug("Symbol %s write %s (%s)", self, value, byte_value)
+            if self.bit_offset is not None:
+                return self.memory.write_bits(
+                    self.offset,
+                    self.bit_offset.offset,
+                    self.bit_offset.size,
+                    byte_value,
+                )
+
+            offset = self.offset if not self.pointer else self._dereference_pointer()
+            return self.memory.write(offset, byte_value)
+
+        return super().write(value)
 
     def _configure_data_type(self):
         self.byte_size = self._struct_size * self.array_length
@@ -391,7 +424,7 @@ class TmcTypes(enum.Enum):
     ITComObjectServer = AdsDataType.UINT64  # TODO: 32 on 32-bit machines...
 
 
-class DataAreaIndexGroup(enum.Enum):
+class DataAreaIndexGroup(enum.IntEnum):
     # <AreaNo AreaType="Internal" CreateSymbols="true">3</AreaNo>
     # e.g., Global_Version.stLibVersion_Tc2_System
     Internal = constants.AdsIndexGroup.PLC_DATA_AREA  # 0x4040
@@ -488,6 +521,74 @@ class TmcDatabase(Database):
         )
 
 
+class SimpleDatabase(Database):
+    _last_symbol: Optional[Symbol]
+    initial_offset: int
+
+    def __init__(self, memory_size: int = 16_000_000, initial_offset: int = 1000):
+        super().__init__()
+
+        self.initial_offset = initial_offset
+        self.data_area = DataArea(
+            index_group=constants.AdsIndexGroup.PLC_DATA_AREA,
+            area_type="dynamic",
+            memory_size=memory_size,
+        )
+        self.index_groups = {
+            constants.AdsIndexGroup.PLC_DATA_AREA: self.data_area,
+        }
+        self._last_symbol = None
+
+    @property
+    def next_offset(self) -> int:
+        """The next memory offset to use for a new symbol."""
+        if self._last_symbol is None:
+            return self.initial_offset
+        return self._last_symbol.memory_range[1] + 1
+
+    def add_basic_symbol(
+        self,
+        name: str,
+        data_type: AdsDataType,
+        array_length: int = 1,
+        comment: Optional[str] = None,
+    ) -> BasicSymbol:
+        """Add a basic (non-struct) symbol."""
+        sym = BasicSymbol(
+            name=name,
+            offset=self.next_offset,
+            data_type=data_type,
+            data_area=self.data_area,
+            array_length=array_length,
+            comment=comment,
+        )
+        self.data_area.symbols[name] = sym
+        return sym
+
+    def add_complex_symbol(
+        self,
+        name: str,
+        cls: Type[ctypes.LittleEndianStructure],
+        array_length: int = 1,
+        comment: Optional[str] = None,
+    ) -> ComplexSymbol:
+        """Add a complex (structured) symbol."""
+        sym = ComplexSymbol(
+            name=name,
+            offset=self.next_offset,
+            data_area=self.data_area,
+            struct_size=ctypes.sizeof(cls),
+            cls=cls,
+            array_length=array_length,
+            comment=comment or f"{cls.__module__}.{cls.__name__} instance",
+        )
+        self.data_area.symbols[name] = sym
+        return sym
+
+    def get_symbol_by_name(self, symbol_name: str) -> Symbol:
+        return self.data_area.symbols[symbol_name]
+
+
 def map_symbols_in_memory(
     memory: PlcMemory, symbols: typing.List[Symbol]
 ) -> typing.Dict[int, typing.List[Symbol]]:
